==> karlender-v0.9.1.tar.gz: karlender-v0.9.1/src/widgets/smart/week_cell.rs <==
use crate::domain::*;
// use crate::store::{gstore::dispatch, store};
use gdk4::subclass::prelude::ObjectSubclassIsExt;
use glib::subclass::signal::Signal;
use glib::SignalHandlerId;
// use gtk::builders::GestureSwipeBuilder;
use gtk::GestureSwipe;
use gtk::{prelude::*, GestureClick};
use std::cell::Cell;

#[widget(extends gtk::Box)]
#[template(file = "week_cell.ui")]
struct WeekCell {
    pub datetime: Cell<Option<KarlenderDateTime>>,

    pub gesture_handler: Cell<Option<(GestureClick, SignalHandlerId)>>,
    pub swipe_handler: Cell<Option<(GestureSwipe, SignalHandlerId)>>,

    #[property_i64]
    pub minutes: Cell<i64>,

    #[signal(Signal::builder("clicked", &[i32::static_type().into()], <()>::static_type().into()).build())]
    clicked: (),

    #[dispose]
    dispose: (),
}

impl WeekCell {
    pub fn new(datetime: KarlenderDateTime) -> Self {
        let week_cell: Self = glib::Object::new(&[]).expect("Failed to create WeekCell");
        week_cell.imp().datetime.set(Some(datetime));
        week_cell
    }

    pub fn constructed(&self) {
        let _self = self;

        self.connect_realize(|s| s.realized());

        let gesture_click = GestureClick::builder().build();
        let id =
            gesture_click.connect_released(glib::clone!(@weak _self => move |_, n_press, _, _| {
                _self.emit_by_name("clicked", &[&n_press.to_value()])
            }));

        self.add_controller(&gesture_click);
        self.imp().gesture_handler.set(Some((gesture_click, id)));

        // let swipe = GestureSwipeBuilder::new().build();
        // let _self = self;
        // let id = swipe.connect_swipe(glib::clone!(@weak _self => move |_gs, x, _y| {
        //     if x > 400. {
        //         dispatch!(crate::store::_GO_PREV)
        //     } else if x < -400. {
        //         dispatch!(crate::store::_GO_NEXT)
        //     }
        // }));
        // self.add_controller(&swipe);
        // self.imp().swipe_handler.set(Some((swipe, id)));
    }

    fn dispose(&self) {
        if let Some((controller, id)) = self.imp().gesture_handler.take() {
            controller.disconnect(id);
            self.remove_controller(&controller);
        }
        if let Some((controller, id)) = self.imp().swipe_handler.take() {
            controller.disconnect(id);
            self.remove_controller(&controller);
        }
    }

    pub fn realized(&self) {
        let d = self.imp().datetime.take();
        let datetime = d.clone();
        self.imp().datetime.set(d);

        if let Some(datetime) = datetime {
            self.set_styles(&datetime);
        }
    }

    fn set_styles(&self, datetime: &KarlenderDateTime) {
        if datetime.minute() == 0 {
            self.add_css_class("border-t-1");
        }
        if datetime.date().weekday().number_from_monday() < 6 {
            self.add_css_class("border-r-1");
        }
    }

    pub fn connect_clicked(&self, f: impl Fn(&Self, i32) + 'static) {
        self.connect_closure(
            "clicked",
            false,
            closure_local!(move |s: Self, num_clicks: i32| {
                f(&s, num_clicks);
            }),
        );
    }

    pub fn datetime(&self) -> KarlenderDateTime {
        let d = self.imp().datetime.take().unwrap();
        let datetime = d.clone();
        self.imp().datetime.set(Some(d));
        datetime
    }
}

==> karlender-v0.9.2.tar.gz: karlender-v0.9.2/src/widgets/smart/week_cell.rs <==
use crate::domain::*;
// use crate::store::{gstore::dispatch, store};
use gdk4::subclass::prelude::ObjectSubclassIsExt;
use glib::subclass::signal::Signal;
use glib::SignalHandlerId;
// use gtk::builders::GestureSwipeBuilder;
use gtk::GestureSwipe;
use gtk::{prelude::*, GestureClick};
use std::cell::Cell;

#[widget(extends gtk::Box)]
#[template(file = "week_cell.ui")]
struct WeekCell {
    pub datetime: Cell<Option<KarlenderDateTime>>,

    pub gesture_handler: Cell<Option<(GestureClick, SignalHandlerId)>>,
    pub swipe_handler: Cell<Option<(GestureSwipe, SignalHandlerId)>>,

    #[property_i64]
    pub minutes: Cell<i64>,

    #[signal(Signal::builder("clicked").param_types([i32::static_type()]).build())]
    clicked: (),

    #[dispose]
    dispose: (),
}

impl WeekCell {
    pub fn new(datetime: KarlenderDateTime) -> Self {
        let week_cell: Self = glib::Object::new();
        week_cell.imp().datetime.set(Some(datetime));
        week_cell
    }

    pub fn constructed(&self) {
        let _self = self;

        self.connect_realize(|s| s.realized());

        let gesture_click = GestureClick::builder().build();
        let id =
            gesture_click.connect_released(glib::clone!(@weak _self => move |_, n_press, _, _| {
                _self.emit_by_name("clicked", &[&n_press.to_value()])
            }));

        self.add_controller(gesture_click.clone());
        self.imp().gesture_handler.set(Some((gesture_click, id)));

        // let swipe = GestureSwipeBuilder::new().build();
        // let _self = self;
        // let id = swipe.connect_swipe(glib::clone!(@weak _self => move |_gs, x, _y| {
        //     if x > 400. {
        //         dispatch!(crate::store::_GO_PREV)
        //     } else if x < -400. {
        //         dispatch!(crate::store::_GO_NEXT)
        //     }
        // }));
        // self.add_controller(&swipe);
        // self.imp().swipe_handler.set(Some((swipe, id)));
    }

    fn dispose(&self) {
        if let Some((controller, id)) = self.imp().gesture_handler.take() {
            controller.disconnect(id);
            self.remove_controller(&controller);
        }
        if let Some((controller, id)) = self.imp().swipe_handler.take() {
            controller.disconnect(id);
            self.remove_controller(&controller);
        }
    }

    pub fn realized(&self) {
        let d = self.imp().datetime.take();
        let datetime = d.clone();
        self.imp().datetime.set(d);

        if let Some(datetime) = datetime {
            self.set_styles(&datetime);
        }
    }

    fn set_styles(&self, datetime: &KarlenderDateTime) {
        if datetime.minute() == 0 {
            self.add_css_class("border-t-1");
        }
        if datetime.date().weekday().number_from_monday() < 6 {
            self.add_css_class("border-r-1");
        }
    }

    pub fn connect_clicked(&self, f: impl Fn(&Self, i32) + 'static) {
        self.connect_closure(
            "clicked",
            false,
            closure_local!(move |s: Self, num_clicks: i32| {
                f(&s, num_clicks);
            }),
        );
    }

    pub fn datetime(&self) -> KarlenderDateTime {
        let d = self.imp().datetime.take().unwrap();
        let datetime = d.clone();
        self.imp().datetime.set(Some(d));
        datetime
    }
}
